@@ -1,4 +1,3 @@
-/* $Xorg: xkmread.c,v 1.3 2000/08/17 19:46:44 cpqbld Exp $ */
 /************************************************************
  Copyright (c) 1994 by Silicon Graphics Computer Systems, Inc.
 
@@ -7,24 +6,23 @@
  fee is hereby granted, provided that the above copyright
  notice appear in all copies and that both that copyright
  notice and this permission notice appear in supporting
- documentation, and that the name of Silicon Graphics not be 
- used in advertising or publicity pertaining to distribution 
+ documentation, and that the name of Silicon Graphics not be
+ used in advertising or publicity pertaining to distribution
  of the software without specific prior written permission.
- Silicon Graphics makes no representation about the suitability 
+ Silicon Graphics makes no representation about the suitability
  of this software for any purpose. It is provided "as is"
  without any express or implied warranty.
- 
- SILICON GRAPHICS DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS 
- SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY 
+
+ SILICON GRAPHICS DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
+ SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
  AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL SILICON
- GRAPHICS BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL 
- DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, 
- DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE 
+ GRAPHICS BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
+ DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
+ DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
  OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION  WITH
  THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
  ********************************************************/
-/* $XFree86: xc/lib/xkbfile/xkmread.c,v 1.6 2002/02/13 22:09:42 herrb Exp $ */
 
 #ifdef HAVE_DIX_CONFIG_H
 #include <dix-config.h>
@@ -52,7 +50,6 @@
 #else
 
 #include <X11/X.h>
-#define	NEED_EVENTS
 #include <X11/Xproto.h>
 #include <X11/keysym.h>
 #include "misc.h"
@@ -76,19 +73,6 @@ XkbInternAtom(Display *dpy,char *str,Bool only_if_exists)
 #define	SEEK_SET 0
 #endif
 
-char *
-_XkbDupString(char *str)
-{
-char *new;
-   
-   if (str==NULL)
-	return NULL;
-   new= (char *)_XkbCalloc(strlen(str)+1,sizeof(char));
-   if (new)
-	strcpy(new,str);
-   return new;
-}
-
 /***====================================================================***/
 
 static XPointer
@@ -318,7 +302,7 @@ XkbDescPtr		xkb;
     if ((tmp= XkmGetCountedString(file,buf,100))<1) {
 	_XkbLibError(_XkbErrBadLength,"ReadXkmKeyTypes",0);
 	return -1;
-    }	
+    }
     nRead+= tmp;
     if (buf[0]!='\0') {
 	if (XkbAllocNames(xkb,XkbTypesNameMask,0,0)!=Success) {
@@ -640,7 +624,7 @@ XkbDescPtr		xkb;
 		Atom name;
 		name= XkbInternAtom(xkb->dpy,buf,0);
 		xkb->names->groups[i]= name;
-	    }	
+	    }
 	    else xkb->names->groups[i]= None;
 	}
     }
@@ -705,7 +689,7 @@ XkbDescPtr		xkb;
 	if (XkbNumGroups(wireMap.num_groups)>0) {
 	    KeySym	*sym;
 	    int		 nSyms;
-	
+
 	    if (XkbNumGroups(wireMap.num_groups)>xkb->ctrls->num_groups)
 		xkb->ctrls->num_groups= wireMap.num_groups;
 	    nSyms= XkbNumGroups(wireMap.num_groups)*wireMap.width;
@@ -1208,7 +1192,7 @@ xkmSectionInfo	tmpTOC;
 char 		name[100];
 
     if ((!file)||(!toc))
-	return 0;
+	return NULL;
     switch (toc->type) {
 	case XkmVirtualModsIndex:
 	case XkmIndicatorsIndex:
@@ -1223,7 +1207,7 @@ char 		name[100];
 	    if ((tmpTOC.type!=toc->type)||(tmpTOC.format!=toc->format)||
 		(tmpTOC.size!=toc->size)||(tmpTOC.offset!=toc->offset)) {
 		_XkbLibError(_XkbErrIllegalContents,"XkmReadFileSectionName",0);
-		return 0;
+		return NULL;
 	    }
 	    if (XkmGetCountedString(file,name,100)>0)
 		return _XkbDupString(name);
